@@ -21,3 +21,5 @@ GOGGLE_SSO_AUTO_CREATE_FIRST_SUPERUSER = getattr(
 )
 GOOGLE_SSO_SESSION_COOKIE_AGE = getattr(settings, "GOOGLE_SSO_SESSION_COOKIE_AGE", 3600)
 GOOGLE_SSO_ENABLED = getattr(settings, "GOOGLE_SSO_ENABLED", True)
+GOGGLE_SSO_SUPERUSER_LIST = getattr(settings, "GOGGLE_SSO_SUPERUSER_LIST", [])
+GOGGLE_SSO_STAFF_LIST = getattr(settings, "GOGGLE_SSO_STAFF_LIST", [])
